/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.geronimo.samples.calc.client;

import java.net.MalformedURLException;
import java.net.URL;
import java.rmi.RemoteException;

import javax.xml.namespace.QName;
import javax.xml.rpc.Service;
import javax.xml.rpc.ServiceException;
import javax.xml.rpc.ServiceFactory;

import org.apache.geronimo.samples.calc.CalculatorService;

public class CalculatorClient {

	public static void main(String[] args) {
		
		int x,y = -1;
		
		try {
			x = Integer.parseInt(args[0]);
			y = Integer.parseInt(args[1]);
		} catch (Exception e) {
			System.out.println("Please provide two valid integer values as your command line arguments");
			System.out.println("Sample: java -jar CalcClient.jar 10 12");
			return;
		}
		
		try {
			String urlstr   = "http://localhost:8080/Calculator/calculator?wsdl";

			URL url =  new URL(urlstr);

			QName qname = new QName("urn:geronimo-samples","CalculatorServiceServlet");

			ServiceFactory factory = ServiceFactory.newInstance();
			Service  service = factory.createService(url, qname);
			
			CalculatorService calc = (CalculatorService)service.getPort(CalculatorService.class);
			
			int sum = calc.addition(x, y);
			
			System.out.println("Sum of "+x+" and "+y+" is "+sum);
			
		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}
}
